@@ -162,6 +162,7 @@ type service struct {
 	evLogger             events.Logger
 	registry             *registry.Registry
 	keyGen               *protocol.KeyGenerator
+	lanChecker           *lanChecker
 
 	dialNow           chan struct{}
 	dialNowDevices    map[protocol.DeviceID]struct{}
@@ -192,6 +193,7 @@ func NewService(cfg config.Wrapper, myID protocol.DeviceID, mdl Model, tlsCfg *t
 		evLogger:             evLogger,
 		registry:             registry,
 		keyGen:               keyGen,
+		lanChecker:           &lanChecker{cfg},
 
 		dialNowDevicesMut: sync.NewMutex(),
 		dialNow:           make(chan struct{}, 1),
@@ -405,9 +407,6 @@ func (s *service) handleHellos(ctx context.Context) error {
 			continue
 		}
 
-		// Determine only once whether a connection is considered local
-		// according to our configuration, then cache the decision.
-		c.isLocal = s.isLAN(c.RemoteAddr())
 		// Wrap the connection in rate limiters. The limiter itself will
 		// keep up with config changes to the rate and whether or not LAN
 		// connections are limited.
@@ -496,13 +495,14 @@ func (s *service) connect(ctx context.Context) error {
 	}
 }
 
-func (*service) bestDialerPriority(cfg config.Configuration) int {
+func (s *service) bestDialerPriority(cfg config.Configuration) int {
 	bestDialerPriority := worstDialerPriority
 	for _, df := range dialers {
 		if df.Valid(cfg) != nil {
 			continue
 		}
-		if prio := df.Priority(); prio < bestDialerPriority {
+		prio := df.New(cfg.Options, s.tlsCfg, s.registry, s.lanChecker).Priority("127.0.0.1")
+		if prio < bestDialerPriority {
 			bestDialerPriority = prio
 		}
 	}
@@ -544,7 +544,14 @@ func (s *service) dialDevices(ctx context.Context, now time.Time, cfg config.Con
 		priorityCutoff := worstDialerPriority
 		connection, connected := s.model.Connection(deviceCfg.DeviceID)
 		if connected {
+			// Set the priority cutoff to the current connection's priority,
+			// so that we don't attempt any dialers with worse priority.
 			priorityCutoff = connection.Priority()
+
+			// Reduce the priority cutoff by the upgrade threshold, so that
+			// we don't attempt dialers that aren't considered a worthy upgrade.
+			priorityCutoff -= cfg.Options.ConnectionPriorityUpgradeThreshold
+
 			if bestDialerPriority >= priorityCutoff {
 				// Our best dialer is not any better than what we already
 				// have, so nothing to do here.
@@ -564,7 +571,7 @@ func (s *service) dialDevices(ctx context.Context, now time.Time, cfg config.Con
 	}
 
 	// Sort the queue in an order we think will be useful (most recent
-	// first, deprioriting unstable devices, randomizing those we haven't
+	// first, deprioritising unstable devices, randomizing those we haven't
 	// seen in a long while). If we don't do connection limiting the sorting
 	// doesn't have much effect, but it may result in getting up and running
 	// quicker if only a subset of configured devices are actually reachable
@@ -657,24 +664,15 @@ func (s *service) resolveDialTargets(ctx context.Context, now time.Time, cfg con
 			continue
 		}
 
-		priority := dialerFactory.Priority()
+		dialer := dialerFactory.New(s.cfg.Options(), s.tlsCfg, s.registry, s.lanChecker)
+		priority := dialer.Priority(uri.Host)
 		if priority >= priorityCutoff {
-			l.Debugf("Not dialing using %s as priority is not better than current connection (%d >= %d)", dialerFactory, dialerFactory.Priority(), priorityCutoff)
+			l.Debugf("Not dialing using %s as priority is not better than current connection (%d >= %d)", dialerFactory, priority, priorityCutoff)
 			continue
 		}
 
-		dialer := dialerFactory.New(s.cfg.Options(), s.tlsCfg, s.registry)
 		nextDialAt.set(deviceID, addr, now.Add(dialer.RedialFrequency()))
 
-		// For LAN addresses, increase the priority so that we
-		// try these first.
-		switch {
-		case dialerFactory.AlwaysWAN():
-			// Do nothing.
-		case s.isLANHost(uri.Host):
-			priority--
-		}
-
 		dialTargets = append(dialTargets, dialTarget{
 			addr:     addr,
 			dialer:   dialer,
@@ -703,7 +701,11 @@ func (s *service) resolveDeviceAddrs(ctx context.Context, cfg config.DeviceConfi
 	return util.UniqueTrimmedStrings(addrs)
 }
 
-func (s *service) isLANHost(host string) bool {
+type lanChecker struct {
+	cfg config.Wrapper
+}
+
+func (s *lanChecker) isLANHost(host string) bool {
 	// Probably we are called with an ip:port combo which we can resolve as
 	// a TCP address.
 	if addr, err := net.ResolveTCPAddr("tcp", host); err == nil {
@@ -717,7 +719,7 @@ func (s *service) isLANHost(host string) bool {
 	return false
 }
 
-func (s *service) isLAN(addr net.Addr) bool {
+func (s *lanChecker) isLAN(addr net.Addr) bool {
 	var ip net.IP
 
 	switch addr := addr.(type) {
@@ -763,7 +765,7 @@ func (s *service) createListener(factory listenerFactory, uri *url.URL) bool {
 
 	l.Debugln("Starting listener", uri)
 
-	listener := factory.New(uri, s.cfg, s.tlsCfg, s.conns, s.natService, s.registry)
+	listener := factory.New(uri, s.cfg, s.tlsCfg, s.conns, s.natService, s.registry, s.lanChecker)
 	listener.OnAddressesChanged(s.logListenAddressesChangedEvent)
 
 	// Retrying a listener many times in rapid succession is unlikely to help,
@@ -1194,9 +1196,9 @@ func (r nextDialRegistry) get(device protocol.DeviceID, addr string) time.Time {
 }
 
 const (
-	dialCoolDownInterval   = 2 * time.Minute
-	dialCoolDownDelay      = 5 * time.Minute
-	dialCoolDownMaxAttemps = 3
+	dialCoolDownInterval    = 2 * time.Minute
+	dialCoolDownDelay       = 5 * time.Minute
+	dialCoolDownMaxAttempts = 3
 )
 
 // redialDevice marks the device for immediate redial, unless the remote keeps
@@ -1215,7 +1217,7 @@ func (r nextDialRegistry) redialDevice(device protocol.DeviceID, now time.Time)
 		return
 	}
 	if dev.attempts == 0 || now.Before(dev.coolDownIntervalStart.Add(dialCoolDownInterval)) {
-		if dev.attempts >= dialCoolDownMaxAttemps {
+		if dev.attempts >= dialCoolDownMaxAttempts {
 			// Device has been force redialed too often - let it cool down.
 			return
 		}
@@ -1226,7 +1228,7 @@ func (r nextDialRegistry) redialDevice(device protocol.DeviceID, now time.Time)
 		dev.nextDial = make(map[string]time.Time)
 		return
 	}
-	if dev.attempts >= dialCoolDownMaxAttemps && now.Before(dev.coolDownIntervalStart.Add(dialCoolDownDelay)) {
+	if dev.attempts >= dialCoolDownMaxAttempts && now.Before(dev.coolDownIntervalStart.Add(dialCoolDownDelay)) {
 		return // Still cooling down
 	}
 	delete(r, device)
@@ -1254,7 +1256,7 @@ func (r nextDialRegistry) sleepDurationAndCleanup(now time.Time) time.Duration {
 		}
 		if dev.attempts > 0 {
 			interval := dialCoolDownInterval
-			if dev.attempts >= dialCoolDownMaxAttemps {
+			if dev.attempts >= dialCoolDownMaxAttempts {
 				interval = dialCoolDownDelay
 			}
 			if now.After(dev.coolDownIntervalStart.Add(interval)) {
