@@ -622,7 +622,7 @@ func (f *sendReceiveFolder) handleDir(file protocol.FileInfo, snap *db.Snapshot,
 		// not MkdirAll because the parent should already exist.
 		mkdir := func(path string) error {
 			err = f.mtimefs.Mkdir(path, mode)
-			if err != nil || f.IgnorePerms || file.NoPermissions {
+			if err != nil || f.IgnorePerms {
 				return err
 			}
 
@@ -631,6 +631,10 @@ func (f *sendReceiveFolder) handleDir(file protocol.FileInfo, snap *db.Snapshot,
 				return err
 			}
 
+			if file.NoPermissions {
+				return nil
+			}
+
 			// Stat the directory so we can check its permissions.
 			info, err := f.mtimefs.Lstat(path)
 			if err != nil {
